{% extends base_template %}

{% load i18n %}

{% block content %}


<h1 class="h2 subtitle">
  {% translate 'Request password reset' %}</h1>

<form method="post">
    {% csrf_token %}
    <p>
        {{ form.credential.label }} <br>
        {{ form.credential }} <br>
        {% for error in form.errors.credential %}
        <span style="color: red;">{{ error }}</span>
        {% endfor %}

    </p>
    <p>
        <input type="submit" class="button is-warning m-2 btn btn-warning" value="{% translate 'send me an email' %}">
    </p>

</form>

{% endblock content %}