{% extends base_template %}

{% load i18n %}

<h1 class="h2 subtitle">{% translate "Sign up" %}</h1>

{% block content %}

<form method="post">
    {% csrf_token %}

    <p>
        {{ form.username.label }} <br>
        {{ form.username}} <br>
        {% for error in form.errors.username %}
        <span style="color: red;">{{ error }}</span>
        {% endfor %}
    </p>
    <p>
        {{ form.email.label }} <br>
        {{ form.email }} <br>
        {% for error in form.errors.email %}
        <span style="color: red;">{{ error }}</span>
        {% endfor %}
    </p>
    <p>
        {{ form.password.label }} <br>
        {{ form.password }} <br>
        {% for error in form.errors.password %}
        <span style="color: red;">{{ error }}</span>
        {% endfor %}
    </p>
    <p>
        {{ form.password2.label }} <br>
        {{ form.password2 }} <br>
        {% for error in form.errors.password2 %}
        <span style="color: red;">{{ error }}</span>
        {% endfor %}
    </p>
        <input type="submit" class="button is-success m-2 btn btn-success" value="{% translate 'Sign Up' %}">


</form>


{% endblock content %}