{% extends base_template %}

{% load i18n %}

{% block content %}

<h2 class="subtitle">{% translate 'Test users' %}</h2>
{% if users %}
<ul>
  {% for user in users %}
  <li>
    <p>{{ user.username }}</p>
  </li>

  {% endfor %}

</ul>

{% endif %}




{% endblock content %}