{% extends base_template %}

{% load i18n %}

{% block content %}

<h1 class="h2 subtitle">
  {% translate 'Login' %}
</h1>

<form method="post">
  {% csrf_token %}

  <p>
      {{ form.credential.label }} <br>
      {{ form.credential }} <br>
      <ul>
        {% for error in form.errors.credential %}
        <li style="color: red;">{{ error }}</li>
        {% endfor %}

      </ul>
  </p>
  <p>
      {{ form.password.label }} <br>
      {{ form.password }} <br>
      <ul>
        {% for error in form.errors.password %}
        <li style="color: red;">{{ error }}</li>
        {% endfor %}
      </ul>
      <br>
  </p>

  <ul>
    <li>
      <a href="{% url 'classic_request_password_reset' %}">
        {% translate 'I forgot my password.' %}
      </a>
    </li>
    <li>
      <p>
        <a href="{% url 'classic_request_resend_confirmation_email' %}">
          {% translate 'My account exists but is unconfirmed, please send me the confirmation email again.' %}
        </a>
      </p>

    </li>
  </ul>

  <input type="submit" class="button is-success m-2 btn btn-success" value="{% translate 'log in' %}">
</form>


{% endblock content %}