{% extends base_template %}
{% load i18n %}

{% block content %}

<h1 class="h2 subtitle">{% translate "Reset Password" %}</h1>

{% translate "user" %}: {{ user.username }} <br>

<form method="post">
    {% csrf_token %}

    <p>
        {{ form.password.label }} <br>
        {{ form.password }} <br>
        <ul>
          {% for error in form.errors.password %}
          <li style="color: red;">{{ error }}</li>
          {% endfor %}

        </ul>

    </p>
    <p>
        {{ form.password2.label }} <br>
        {{ form.password2 }} <br>
        <ul>
          {% for error in form.errors.password2 %}
          <li style="color: red;">{{ error }}</li>
          {% endfor %}

        </ul>

    </p>
    <p>
        <input type="submit" class="button is-success m-2 btn btn-success" value="{% translate 'confirm' %}">
    </p>

</form>



{% endblock content %}